@@ -10,9 +10,9 @@ echo "Project dir is: ${project_dir}"
 
 
 if [ "${TRAVIS_OS_NAME}" == "linux" ]; then
-	# Install base Qt5 repos for linux
+    # Install base Qt5 repos for linux
     sudo apt-get -qq update
-    sudo add-apt-repository ppa:beineri/opt-qt58-trusty -y
+    sudo add-apt-repository ppa:beineri/opt-qt-5.12.10-xenial -y
     sudo apt-get update -qq
 
 elif [ "${TRAVIS_OS_NAME}" == "osx" ]; then
@@ -24,4 +24,4 @@ fi
 
 echo "Done!"
 
-exit 0
\ No newline at end of file
+exit 0
