@@ -11,9 +11,12 @@ echo "Project dir is: ${project_dir}"
 
 
 if [ "${TRAVIS_OS_NAME}" == "linux" ]; then
-    sudo apt-get -y install qt58base qt58charts-no-lgpl qt58svg 
+    sudo apt-get install mesa-common-dev
+#    sudo apt install libglu1-mesa-dev freeglut3-dev
+    sudo apt-get install build-essential libgl1-mesa-dev
+    sudo apt-get -y install qt512base qt512charts-no-lgpl  qt512svg
     # sudo apt-get install qt5-default qttools5-dev qttools5-dev-tools qtbase5-dev qtbase5-dev-tools qttranslations5-l10n libqt5svg5-dev
-    source /opt/qt58/bin/qt58-env.sh
+    source /opt/qt512/bin/qt512-env.sh
 
 
 elif [ "${TRAVIS_OS_NAME}" == "osx" ]; then
@@ -29,4 +32,4 @@ fi
 
 echo "Done!"
 
-exit 0
\ No newline at end of file
+exit 0
