@@ -1,11 +1,11 @@
 /***************************************************************************
  SocNetV: Social Network Visualizer
- version: 2.5
+ version: 2.8
  Written in Qt
  
                          graph.h  -  description
                              -------------------
-    copyright         : (C) 2005-2019 by Dimitris B. Kalamaras
+    copyright         : (C) 2005-2021 by Dimitris B. Kalamaras
     project site      : https://socnetv.org
 
  ***************************************************************************/
@@ -33,6 +33,8 @@
 #include <QDateTime> 	// used in exporting centrality files
 #include <QList>
 #include <QHash>
+#include <QMultiHash>
+#include <QMultiMap>
 #include <QTextStream>
 #include <QThread>
 
@@ -84,7 +86,7 @@ typedef QHash <int, int> H_Int;
 typedef QHash <qreal, int> H_f_i;
 typedef QPair <qreal, bool> pair_f_b;
 typedef QPair <int, pair_f_b > pair_i_fb;
-typedef QHash <int, pair_i_fb > H_edges;
+typedef QMultiHash <int, pair_i_fb > H_edges;
 typedef QHash<QString, bool> H_StrToBool;
 typedef QList<int> L_int;
 typedef QVector<int> V_int;
@@ -154,17 +156,17 @@ public slots:
                         const int &labelSize,
                         const QPointF &p,
                         const QString &shape,
-                        const QString &iconPath = QString::null,
+                        const QString &iconPath = QString(),
                         const bool &signalMW = false
             );
 
     void graphFileLoaded(const int &fileType,
-                         const QString &fName=QString::null,
-                         const QString &netName=QString::null,
+                         const QString &fName=QString(),
+                         const QString &netName=QString(),
                          const int &totalNodes=0,
                          const int &totalLinks=0,
                          const int &edgeDirType=0,
-                         const QString &message=QString::null);
+                         const QString &message=QString());
 
     void vertexRemoveDummyNode(int);
 
@@ -179,7 +181,7 @@ public slots:
                       const QString &color ,
                       const int &type=0,
                       const bool &drawArrows=true, const bool &bezier=false,
-                      const QString &label=QString::null,
+                      const QString &label=QString(),
                       const bool &signalMW=true);
 
     void edgeCreateWebCrawler (const int &source, const int &target);
@@ -266,11 +268,11 @@ signals:
                              const qreal &density);
 
     void signalGraphLoaded (const int &fileType,
-                            const QString &fileName=QString::null,
-                            const QString &netName=QString::null,
+                            const QString &fileName=QString(),
+                            const QString &netName=QString(),
                             const int &totalNodes=0,
                             const int &totalLinks=0,
-                            const QString &message=QString::null );
+                            const QString &message=QString() );
 
 
 
@@ -280,7 +282,7 @@ signals:
 
     void signalNodeClickedInfo(const int &number=0,
                                     const QPointF &p=QPointF(),
-                                    const QString &label=QString::null,
+                                    const QString &label=QString(),
                                     const int &inDegree=0,
                                     const int &outDegree=0,
                                     const qreal &clc=0);
@@ -358,7 +360,7 @@ signals:
 
     void setNodeSize(const int &v, const int &size);
 
-    void setNodeShape(const int &v, const QString &shape, const QString &iconPath=QString::null);
+    void setNodeShape(const int &v, const QString &shape, const QString &iconPath=QString());
 
     void setNodeColor(const int &v, const QString &color);
 
@@ -422,8 +424,12 @@ public:
 
     /* INIT AND CLEAR*/
     Graph(GraphicsWidget *graphicsWidget);
+
+    void initSignalSlots();
+
     void clear(const QString &reason="");
-        ~Graph();
+
+    ~Graph();
 
     void setSocNetV_Version (QString ver) { VERSION = ver; }
 
@@ -437,7 +443,7 @@ public:
                     const QString m_codecName,
                     const int format,
                     const int two_sm_mode,
-                    const QString delimiter=QString::null);
+                    const QString delimiter=QString());
 
     void graphSave(const QString &fileName,
                    const int &fileType,
@@ -492,6 +498,10 @@ public:
 
     QList<int> vertexNeighborhoodList(const int &v1);
 
+    // Only in Qt 5.15
+//    QSet<int> vertexNeighborhoodSet(const int &v1);
+
+
     bool vertexIsolated(const int &v1) const;
 
     int vertexExists(const int &v1 );
@@ -512,9 +522,9 @@ public:
 
     int vertexSize(const int &v) const;
 
-    void vertexShapeSetDefault (const QString, const QString &iconPath=QString::null);
+    void vertexShapeSetDefault (const QString, const QString &iconPath=QString());
 
-    void vertexShapeSet(const int &v, const QString &shape, const QString &iconPath=QString::null);
+    void vertexShapeSet(const int &v, const QString &shape, const QString &iconPath=QString());
 
     QString vertexShape(const int &v);
 
@@ -1215,12 +1225,12 @@ private:
 
     QList<SelectedEdge> m_selectedEdges;
 
-    QHash <int, int> influenceRanges, influenceDomains;
+    QMultiHash <int, int> influenceRanges, influenceDomains;
 
-    QHash <int, int> m_vertexPairsNotConnected;
+    QMultiHash <int, int> m_vertexPairsNotConnected;
     QHash <int, int> m_vertexPairsUnilaterallyConnected;
 
-    QMap <int, L_int > m_cliques;
+    QMultiMap <int, L_int > m_cliques;
     QHash <int, QSet<int> > neighboursHash;
 
     QList <qreal> m_clusteringLevel;
@@ -1327,7 +1337,7 @@ private:
     bool calculatedGraphDensity, calculatedGraphWeighted;
     bool m_graphIsDirected, m_graphIsSymmetric, m_graphIsWeighted, m_graphIsConnected;
 
-    int cliqueCensusRecursion;
+    int csRecDepth;
 
     QString VERSION, fileName, m_graphName, initEdgeColor, initVertexColor,
         initVertexNumberColor, initVertexLabelColor;
