@@ -1,11 +1,11 @@
 /***************************************************************************
  SocNetV: Social Network Visualizer 
- version: 2.5
+ version: 2.8
  Written in Qt
  
                          graphvertex.cpp  -  description
                              -------------------
-    copyright         : (C) 2005-2019 by Dimitris B. Kalamaras
+    copyright         : (C) 2005-2021 by Dimitris B. Kalamaras
     project site      : https://socnetv.org
 
  ***************************************************************************/
@@ -141,7 +141,7 @@ GraphVertex::GraphVertex(const int &name) {
 void GraphVertex::relationSet(int newRel) {
     qDebug() << "GraphVertex::relationSet() - vertex:" << name()
              << "current relation:" << m_curRelation
-             << "settting new relation: " << newRel;
+             << "setting new relation: " << newRel;
     // first make false all edges of current relation
     edgeFilterByRelation(m_curRelation, false);
     // then make true all edges of new relation
@@ -174,7 +174,7 @@ void GraphVertex::edgeAddTo (const int &v2, const qreal &weight, const QString &
             << name() << " -> "<< v2 << " weight "<< weight
                << " relation " << m_curRelation;
     // do not use [] operator - silently creates an item if key do not exist
-    m_outEdges.insertMulti(
+    m_outEdges.insert(
                 v2, pair_i_fb(m_curRelation, pair_f_b(weight, true) ) );
     setOutLinkColor(v2, color);
     setOutEdgeLabel(v2, label);
@@ -225,7 +225,7 @@ void GraphVertex::edgeAddFrom (const int &v1, const qreal &weight) {
     qDebug() <<"GraphVertex::edgeAddFrom() - new inbound edge"
             << name() << " <- "<< v1 << " weight "<< weight
                << " relation " << m_curRelation;
-    m_inEdges.insertMulti(
+    m_inEdges.insert(
                 v1, pair_i_fb (m_curRelation, pair_f_b(weight, true) ) );
 }
 
@@ -248,7 +248,7 @@ void GraphVertex::changeOutEdgeWeight(const int &target, const qreal &weight){
     qDebug() << " *** m_outEdges.count " <<
                 m_outEdges.count();
     qDebug() << " create new relation-weight pair ";
-    m_outEdges.insertMulti(
+    m_outEdges.insert(
                 target, pair_i_fb(m_curRelation, pair_f_b(weight, true) ) );
     qDebug() << " *** m_outEdges.count " << m_outEdges.count();
 }
@@ -576,7 +576,7 @@ QHash<int, qreal> GraphVertex::reciprocalEdgesHash(){
 //                    qDebug() << "GraphVertex::reciprocalEdgesHash() - of vertex "
 //                             << this->name()
 //                             << "Found reciprocal edge with   " << it1.key();
-                    m_reciprocalEdges.insertMulti(it1.key(), m_weight);
+                    m_reciprocalEdges.insert(it1.key(), m_weight);
                 }
             }
         }
@@ -593,7 +593,8 @@ QHash<int, qreal> GraphVertex::reciprocalEdgesHash(){
 
 
 /**
- * @brief Returns a list of all neighbors mutually connected to this vertex in the active relation
+ * @brief Returns a list of all neighbors mutually connected to this vertex in the active relation.
+ * The returned list does not include the vertex itself, even if it self-connected.
  * Same as calling GraphVertex::reciprocalEdgesHash().keys() which returns a QList of int keys,
  * where each key is a vertex reciprocally connected to this one.
  * @return  QList<int>
@@ -611,7 +612,7 @@ QList<int> GraphVertex::neighborhoodList(){
             edgeStatus=it1.value().second.second;
             if ( edgeStatus == true) {
                 m_weight=it1.value().second.first;
-                if (this->hasEdgeFrom (it1.key()) == m_weight ) {
+                if ( this->name() != it1.key() && this->hasEdgeFrom (it1.key()) == m_weight ) {
                     m_neighborhoodList << it1.key();
 //                qDebug() <<  "GraphVertex::neighborhoodList() - mutually connected neighbor="
 //                          << it1.key()
@@ -623,11 +624,11 @@ QList<int> GraphVertex::neighborhoodList(){
         ++it1;
     }
 
-    qDebug() << "GraphVertex::neighborhoodList() - of vertex " << this->name()
-             <<  "final list"
-              <<m_neighborhoodList
-                 <<" count"
-                 << m_neighborhoodList.count();
+//    qDebug() << "GraphVertex::neighborhoodList() - of vertex " << this->name()
+//             <<  "final list"
+//              <<m_neighborhoodList
+//                 <<" count"
+//                 << m_neighborhoodList.count();
 
 //    qDebug() <<  "GraphVertex::neighborhoodList() - reporting localDegree "
 //                 << this->localDegree();
@@ -849,23 +850,23 @@ qreal GraphVertex::hasEdgeFrom(const int &v2, const bool &allRelations){
                 edgeStatus=it1.value().second.second;
                 if ( edgeStatus == true) {
                     m_weight=it1.value().second.first;
-                    qDebug()<< "GraphVertex::hasEdgeFrom() - "<<  this->name()
-                            << "<-" << v2 << " = "<< m_weight;
+//                    qDebug()<< "GraphVertex::hasEdgeFrom() - "<<  this->name()
+//                            << "<-" << v2 << " = "<< m_weight;
                     return m_weight;
                 }
                 else {
-                    qDebug()<< "GraphVertex::hasEdgeFrom() - "<<  this->name()
-                            << "<-" << v2 << " = "<< m_weight
-                            << " but edgeStatus " << edgeStatus;
+//                    qDebug()<< "GraphVertex::hasEdgeFrom() - "<<  this->name()
+//                            << "<-" << v2 << " = "<< m_weight
+//                            << " but edgeStatus " << edgeStatus;
                     return 0;
                 }
             }
         }
         else {
                 m_weight=it1.value().second.first;
-                qDebug()<< "GraphVertex::hasEdgeFrom() - "<<  this->name()
-                        << "<-" << v2 << " = "<< m_weight
-                           << "relation"<<it1.value().first;
+//                qDebug()<< "GraphVertex::hasEdgeFrom() - "<<  this->name()
+//                        << "<-" << v2 << " = "<< m_weight
+//                           << "relation"<<it1.value().first;
                 return m_weight;
 
 
@@ -919,8 +920,8 @@ qreal GraphVertex::distance (const int &v1) {
         }
         ++it1;
     }
-    qDebug() <<"GraphVertex::distance() - d("
-               << name() << " --> "<< v1 << ") = "<< d;
+//    qDebug() <<"GraphVertex::distance() - d("
+//               << name() << " --> "<< v1 << ") = "<< d;
 
     return d;
 }
@@ -1012,7 +1013,7 @@ void GraphVertex::cliqueAdd (const QList<int> &clique) {
            << name()
            << "in a clique with:"
            << clique;
-    m_cliques.insertMulti(clique.size(), clique);
+    m_cliques.insert(clique.size(), clique);
 }
 
 
