@@ -1,11 +1,11 @@
 /***************************************************************************
  SocNetV: Social Network Visualizer
- version: 2.5
+ version: 2.8
  Written in Qt
  
                          mainwindow.h  -  description
                              -------------------
-    copyright         : (C) 2005-2019 by Dimitris B. Kalamaras
+    copyright         : (C) 2005-2021 by Dimitris B. Kalamaras
     blog              : http://dimitris.apeiro.gr
     project site      : https://socnetv.org
 
@@ -51,7 +51,7 @@
 #include "forms/dialogfilteredgesbyweight.h"
 #include "forms/dialogdatasetselect.h"
 
-static const QString VERSION="2.5";
+static const QString VERSION="2.8";
 
 static const int USER_MSG_INFO=0;
 static const int USER_MSG_CRITICAL=1;
@@ -71,7 +71,7 @@ class QCheckBox;
 class QProgressDialog;
 class QPushButton;
 class QToolButton;
-class QLCDNumber;
+class QPageSize;
 class QSlider;
 class QComboBox;
 class QGroupBox;
@@ -118,6 +118,8 @@ class DialogExportImage;
 
 class DialogSettings;
 
+class DialogSystemInfo;
+
 class TextEditor;
 
 
@@ -172,7 +174,7 @@ public:
 public slots:
     //NETWORK MENU
     void slotNetworkNew();
-    void slotNetworkFileChoose(QString m_fileName = QString::null,
+    void slotNetworkFileChoose(QString m_fileName = QString(),
                                int m_fileFormat = -1,
                                const bool &checkSelectFileType = true);
     void slotNetworkFileDialogFileSelected(const QString &fileName);
@@ -183,11 +185,11 @@ public slots:
     bool slotNetworkFilePreview(const QString &, const int &);
     void slotNetworkFileLoad ( const QString, const QString, const int );
     void slotNetworkFileLoaded(const int &type,
-                               const QString &fName=QString::null,
-                               const QString &netName=QString::null,
+                               const QString &fName=QString(),
+                               const QString &netName=QString(),
                                const int &totalNodes=0,
                                const int &totalEdges=0,
-                               const QString &message=QString::null);
+                               const QString &message=QString());
     void slotNetworkFileLoadRecent();
     void slotNetworkSavedStatus(const int &status);
     void slotNetworkFileView();
@@ -221,9 +223,10 @@ public slots:
 
     void slotNetworkExportPDFDialog();
     void slotNetworkExportPDF(QString &pdfName,
-                              const QPrinter::Orientation &orientation,
+                              const QPageLayout::Orientation &orientation,
                               const int &dpi,
-                              const QPrinter::PrinterMode printerMode);
+                              const QPrinter::PrinterMode printerMode,
+                              const QPageSize &pageSize);
     void slotNetworkExportPajek();
     void slotNetworkExportSM();
     bool slotNetworkExportDL();
@@ -291,11 +294,14 @@ public slots:
                                const bool &delayedRequests);
 
     //EDIT MENU
+    void slotEditDragModeSelection(bool);
+    void slotEditDragModeScroll(bool);
+
     void slotEditRelationsClear();
-    void slotEditRelationAdd(QString newRelationName=QString::null,
+    void slotEditRelationAdd(QString newRelationName=QString(),
                              const bool &changeRelation=true);
     void slotEditRelationChange(const int relIndex=RAND_MAX);
-    void slotEditRelationRename(QString newName=QString::null);
+    void slotEditRelationRename(QString newName=QString());
 
     void slotEditOpenContextMenu(const QPointF & mPos);
     void slotEditSelectionChanged (const int &selNodes, const int &selEdges);
@@ -316,7 +322,7 @@ public slots:
     void slotEditNodeFindDialog();
     void slotEditNodeFind(const QStringList &list,
                           const QString &searchType,
-                          const QString &indexStr=QString::null);
+                          const QString &indexStr=QString());
     void slotEditNodeRemove();
     void slotEditNodeOpenContextMenu();
     void slotEditNodePropertiesDialog();
@@ -334,8 +340,8 @@ public slots:
     void slotEditNodeColorAll(QColor color=QColor());
     void slotEditNodeSizeAll(int newSize=0, const bool &normalized=false);
     void slotEditNodeShape(const int &vertex = 0,
-                           QString shape=QString::null,
-                           QString nodeIconPath=QString::null);
+                           QString shape=QString(),
+                           QString nodeIconPath=QString());
     void slotEditNodeNumberSize(int v1=0, int newSize=0, const bool prompt=true);
     void slotEditNodeNumberDistance(int v1=0, int newSize=0);
     void slotEditNodeNumbersColor(const int &v1=0, QColor color=QColor());
@@ -486,7 +492,7 @@ public slots:
     void slotOptionsEdgeLabelsVisibility(bool toggle);
     void slotOptionsEdgeWeightNumbersVisibility(bool toggle);
     void slotOptionsEdgeWeightsDuringComputation(bool);
-    void slotOptionsEdgeThicknessPerWeight(bool toogle);
+    void slotOptionsEdgeThicknessPerWeight(bool toggle);
     void slotOptionsEdgesBezier(bool toggle);
     void slotOptionsEdgeArrowsVisibility(bool toggle);
 
@@ -497,7 +503,7 @@ public slots:
     void slotOptionsWindowStatusbarVisibility(bool toggle);
     void slotOptionsWindowLeftPanelVisibility(bool toggle);
     void slotOptionsWindowRightPanelVisibility(bool toggle);
-    void slotOptionsWindowFullScreen(bool toogle);
+    void slotOptionsWindowFullScreen(bool toggle);
 
     void slotOptionsDebugMessages(bool toggle);
 
@@ -522,18 +528,19 @@ public slots:
     void slotHelpCheckUpdateDialog();
     void slotHelpCheckUpdateParse(QNetworkReply *reply);
     void slotHelpCreateTips();
+    void slotHelpSystemInfo();
     void slotHelpAbout();
     void slotAboutQt();
-    void slotHelpMessageToUserInfo(const QString text=QString::null);
-    void slotHelpMessageToUserError(const QString text=QString::null);
+    void slotHelpMessageToUserInfo(const QString text=QString());
+    void slotHelpMessageToUserError(const QString text=QString());
     int slotHelpMessageToUser(const int type=0,
-                              const QString statusMsg=QString::null,
-                              const QString text=QString::null,
-                              const QString info=QString::null,
+                              const QString statusMsg=QString(),
+                              const QString text=QString(),
+                              const QString info=QString(),
                               QMessageBox::StandardButtons buttons=QMessageBox::NoButton,
                               QMessageBox::StandardButton defBtn=QMessageBox::Ok,
-                              const QString btn1=QString::null,
-                              const QString btn2=QString::null
+                              const QString btn1=QString(),
+                              const QString btn2=QString()
                                );
 
 
@@ -584,8 +591,6 @@ private:
     QStringList iconPathList;
     QStringList nodeShapeList;
 
-    DialogFilterEdgesByWeight *m_DialogEdgeFilterByWeight;
-
     DialogWebCrawler *m_WebCrawlerDialog;
     DialogDataSetSelect *m_datasetSelectDialog;
 
@@ -596,6 +601,7 @@ private:
     DialogNodeFind *m_nodeFindDialog;
 
     DialogEdgeDichotomization *m_edgeDichotomizationDialog;
+    DialogFilterEdgesByWeight *m_DialogEdgeFilterByWeight;
 
     DialogRandErdosRenyi *m_randErdosRenyiDialog;
     DialogRandSmallWorld *m_randSmallWorldDialog;
@@ -603,12 +609,14 @@ private:
     DialogRandRegular *m_randRegularDialog;
     DialogRandLattice *m_randLatticeDialog;
 
-    DialogSettings *m_settingsDialog;
     DialogSimilarityPearson *m_dialogSimilarityPearson;
     DialogSimilarityMatches *m_dialogSimilarityMatches;
     DialogDissimilarities *m_dialogdissimilarities;
     DialogClusteringHierarchical *m_dialogClusteringHierarchical;
 
+    DialogSettings *m_settingsDialog;
+    DialogSystemInfo *m_systemInfoDialog;
+
     DialogPreviewFile *m_dialogPreviewFile;
     QList<QTextCodec *> codecs;
     QString userSelectedCodecName;
@@ -667,8 +675,9 @@ private:
     QAction *networkRandomSmallWorldAct;
     QAction *networkRandomRegularSameDegreeAct;
     QAction *networkRandomLatticeAct;
+    QAction *networkWebCrawlerAct;
 
-    QAction *optionsNodeNumbersVisibilityAct, *optionsNodeLabelsVisibilityAct, *optionsNodeNumbersInsideAct;
+    QAction *editDragModeScrollAct, *editDragModeSelectAct;
     QAction *editNodeSelectNoneAct, *editNodeSelectAllAct;
     QAction *editNodeSelectedToStarAct, *editNodeSelectedToCycleAct;
     QAction *editNodeSelectedToLineAct, *editNodeSelectedToCliqueAct;
@@ -686,19 +695,21 @@ private:
     QAction *editNodeColorAll, *editEdgeColorAllAct,
             *editNodeNumbersColorAct,*editNodeLabelsColorAct,
             *editEdgesCocitationAct;
+
+    QAction *optionsNodeNumbersVisibilityAct, *optionsNodeLabelsVisibilityAct, *optionsNodeNumbersInsideAct;
     QAction *optionsEdgeThicknessPerWeightAct, *optionsEdgeWeightNumbersAct;
     QAction *optionsEdgesVisibilityAct;
     QAction *optionsEdgeArrowsAct, *drawEdgesBezier, *optionsEdgeWeightConsiderAct;
     QAction *optionsEdgeLabelsAct;
     QAction *backgroundImageAct,*changeBackColorAct;
     QAction *fullScreenModeAct;
-    QAction *helpAboutApp, *helpAboutQt, *helpApp, *tipsApp;
-    QAction *helpCheckUpdatesApp;
     QAction *openSettingsAct;
 
-    QCheckBox *styleSheetCheck;
+    QAction *helpAboutApp, *helpAboutQt, *helpApp, *tipsApp;
+    QAction *helpSystemInfoAct, *helpCheckUpdatesApp;
+
+
 
-    QAction *networkWebCrawlerAct;
 
     QAction *netDensity, *analyzeGraphReciprocityAct, *analyzeGraphSymmetryAct;
     QAction *analyzeGraphDistanceAct, *averGraphDistanceAct;
@@ -754,6 +765,8 @@ private:
     int statusBarDuration, progressCounter;
     int fileType, maxNodes;
     int fortuneCookiesCounter;
+    int windowMinWidth, windowMinHeight;
+
     //QString VERSION;
 
     bool inverseWeights, askedAboutWeights;
